==> welltested-2.1.4.tar.gz: lib/src/executors/unit_test_executor.dart <==
/*
 * Created on May 1st 2023
 *
 * Copyright (C) 2023 Welltested AI - All Rights Reserved
 * The code in this file is Intellectutal Property of Welltested AI.
 * and can't be edited, redistributed or used without a valid license of it's product (Welltested)[https://welltested.ai]
 */
import 'package:analyzer/dart/ast/ast.dart';
import 'package:welltested/src/extensions/class_element_extension.dart';
import 'package:welltested/src/extensions/string_extensions.dart';
import 'package:welltested/src/models/test_request/base_test_request.dart';
import 'package:welltested/src/models/test_request/class_test_request.dart';
import 'package:welltested/src/models/test_request/extension_test_request.dart';
import 'package:welltested/src/models/test_request/global_test_request.dart';
import 'package:welltested/src/repositories/generations_repository.dart';
import 'package:welltested/src/utilities/utilities.dart';
import 'package:welltested/src/visitors/function_body_visitor.dart';

class UnitTestExecutor {
  final GenerationRepository _generationRepository;
  UnitTestExecutor(this._generationRepository);
  Future<UnitTestRequest?> prepareRequest(
      {required MapEntry<String, Declaration> method,
      required CompilationUnit compilationUnit,
      required String fileImport,
      required ClassDeclaration? classAstNode,
      required ExtensionDeclaration? extensionAstNode,
      required String? className,
      required Map<String, MethodDeclaration>? methodAstNodes,
      required List<String> excludedMethods}) async {
    if (classAstNode != null || extensionAstNode != null) {
      assert(methodAstNodes != null);
      assert(className != null);
    }
    if (excludedMethods.contains(method.key) || _isPrivate(method.key))
      return null;

    final ast_method = method.value;
    final FunctionBodyVisitor functionBodyVisitor = FunctionBodyVisitor();
    ast_method.visitChildren(functionBodyVisitor);
    final processedModels =
        await functionBodyVisitor.classElements.processModels();
    final staticMethods = <String>[];
    for (final method in functionBodyVisitor.staticMethods) {
      final code = (await getResolvedAstNodeForElement(method)).toSource();
      if (code.length < 1800)
        staticMethods.add(code);
      else if (code.length < 2500) staticMethods.add(code.shrink);
    }
    if (extensionAstNode != null) {
      return ExtensionTestRequest(
        extensionName: className!,
        extensionNode: extensionAstNode,
        methodAstNodes: methodAstNodes!,
        compilationUnit: compilationUnit,
        functionName: method.key,
        currentMethod: method.value,
        fileImportPath: fileImport,
        nestedMethods: functionBodyVisitor.nestedMethods,
        simpleModels: processedModels[0],
        complexModels: processedModels[1],
        staticMethods: staticMethods,
        callFlows: functionBodyVisitor.callFlows,
        variableDeclarations: functionBodyVisitor.updateVariableNameNType,
      );
    } else if (classAstNode != null) {
      return ClassTestRequest(
        className: className!,
        classNode: classAstNode,
        methodAstNodes: methodAstNodes!,
        compilationUnit: compilationUnit,
        functionName: method.key,
        currentMethod: method.value,
        fileImportPath: fileImport,
        nestedMethods: functionBodyVisitor.nestedMethods,
        simpleModels: processedModels[0],
        complexModels: processedModels[1],
        staticMethods: staticMethods,
        callFlows: functionBodyVisitor.callFlows,
        variableDeclarations: functionBodyVisitor.updateVariableNameNType,
      );
    } else {
      return GlobalTestRequest(
          compilationUnit: compilationUnit,
          functionName: method.key,
          currentMethod: method.value,
          fileImportPath: fileImport,
          nestedMethods: functionBodyVisitor.nestedMethods,
          simpleModels: processedModels[0],
          complexModels: processedModels[1],
          staticMethods: staticMethods,
          callFlows: functionBodyVisitor.callFlows,
          variableDeclarations: functionBodyVisitor.updateVariableNameNType);
    }
  }

  Stream<String> dryRun(UnitTestRequest testRequestData) =>
      _generationRepository.dryRun(testRequestData);

      Stream<String> testability(UnitTestRequest testRequestData) =>
      _generationRepository.checkTestability(testRequestData);

  Future<Map<String, dynamic>> buildUnitTests(UnitTestRequest test) =>
      _generationRepository.buildUnitTests(test);

  Future<Map<String, dynamic>> updateTest(
      UnitTestRequest testRequestData, String fixedTest) {
    return _generationRepository.updateTest(testRequestData, fixedTest);
  }

  Future<Map<String, dynamic>> testcases(UnitTestRequest testRequest) {
    return _generationRepository.testcases(testRequest);
  }

  //TODO: Move to extenion or utility class
  bool _isPrivate(String name) {
    return name.startsWith("_");
  }
}

==> welltested-2.2.0.tar.gz: lib/src/executors/unit_test_executor.dart <==
/*
 * Created on May 1st 2023
 *
 * Copyright (C) 2023 Welltested AI - All Rights Reserved
 * The code in this file is Intellectutal Property of Welltested AI.
 * and can't be edited, redistributed or used without a valid license of it's product (Welltested)[https://welltested.ai]
 */
import 'package:analyzer/dart/ast/ast.dart';
import 'package:welltested/src/extensions/class_element_extension.dart';
import 'package:welltested/src/extensions/string_extensions.dart';
import 'package:welltested/src/models/test_request/base_test_request.dart';
import 'package:welltested/src/models/test_request/class_test_request.dart';
import 'package:welltested/src/models/test_request/extension_test_request.dart';
import 'package:welltested/src/models/test_request/global_test_request.dart';
import 'package:welltested/src/repositories/generations_repository.dart';
import 'package:welltested/src/utilities/utilities.dart';
import 'package:welltested/src/visitors/function_body_visitor.dart';

class UnitTestExecutor {
  final GenerationRepository _generationRepository;
  UnitTestExecutor(this._generationRepository);
  Future<UnitTestRequest?> prepareRequest(
      {required MapEntry<String, Declaration> method,
      required CompilationUnit compilationUnit,
      required String fileImport,
      required ClassDeclaration? classAstNode,
      required ExtensionDeclaration? extensionAstNode,
      required String? className,
      required Map<String, MethodDeclaration>? methodAstNodes,
      required List<String> excludedMethods}) async {
    if (classAstNode != null || extensionAstNode != null) {
      assert(methodAstNodes != null);
      assert(className != null);
    }
    if (excludedMethods.contains(method.key) || _isPrivate(method.key))
      return null;

    final ast_method = method.value;
    final FunctionBodyVisitor functionBodyVisitor = FunctionBodyVisitor();
    ast_method.visitChildren(functionBodyVisitor);
    final processedModels =
        await functionBodyVisitor.classElements.processModels();
    final staticMethods = <String>[];
    for (final method in functionBodyVisitor.staticMethods) {
      final code = (await getResolvedAstNodeForElement(method)).toSource();
      if (code.length < 1800)
        staticMethods.add(code);
      else if (code.length < 2500) staticMethods.add(code.shrink);
    }
    if (extensionAstNode != null) {
      return ExtensionTestRequest(
        extensionName: className!,
        extensionNode: extensionAstNode,
        methodAstNodes: methodAstNodes!,
        compilationUnit: compilationUnit,
        functionName: method.key,
        currentMethod: method.value,
        fileImportPath: fileImport,
        nestedMethods: functionBodyVisitor.nestedMethods.keys.toList(),
        simpleModels: processedModels[0],
        complexModels: processedModels[1],
        staticMethods: staticMethods,
        callFlows: functionBodyVisitor.callFlows,
        variableDeclarations:
            functionBodyVisitor.updateVariableNameNType.keys.toList(),
      );
    } else if (classAstNode != null) {
      return ClassTestRequest(
        className: className!,
        classNode: classAstNode,
        methodAstNodes: methodAstNodes!,
        compilationUnit: compilationUnit,
        functionName: method.key,
        currentMethod: method.value,
        fileImportPath: fileImport,
        nestedMethods: functionBodyVisitor.nestedMethods.keys.toList(),
        simpleModels: processedModels[0],
        complexModels: processedModels[1],
        staticMethods: staticMethods,
        callFlows: functionBodyVisitor.callFlows,
        variableDeclarations:
            functionBodyVisitor.updateVariableNameNType.keys.toList(),
      );
    } else {
      return GlobalTestRequest(
          compilationUnit: compilationUnit,
          functionName: method.key,
          currentMethod: method.value,
          fileImportPath: fileImport,
          nestedMethods: functionBodyVisitor.nestedMethods.keys.toList(),
          simpleModels: processedModels[0],
          complexModels: processedModels[1],
          staticMethods: staticMethods,
          callFlows: functionBodyVisitor.callFlows,
          variableDeclarations:
              functionBodyVisitor.updateVariableNameNType.keys.toList());
    }
  }

  Stream<String> dryRun(UnitTestRequest testRequestData) =>
      _generationRepository.dryRun(testRequestData);

  Stream<String> testability(UnitTestRequest testRequestData) =>
      _generationRepository.checkTestability(testRequestData);

  Future<Map<String, dynamic>> buildUnitTests(UnitTestRequest test) =>
      _generationRepository.buildUnitTests(test);

  Future<Map<String, dynamic>> updateTest(
      UnitTestRequest testRequestData, String fixedTest) {
    return _generationRepository.updateTest(testRequestData, fixedTest);
  }

  Future<Map<String, dynamic>> testcases(UnitTestRequest testRequest) {
    return _generationRepository.testcases(testRequest);
  }

  //TODO: Move to extenion or utility class
  bool _isPrivate(String name) {
    return name.startsWith("_");
  }
}
